=======
History
=======

0.0.1 (2020-08-17)
------------------

* First release on PyPI.

0.0.2 (2020-08-17)
------------------

* Restricted to tex extension only.


0.0.3 (2020-08-18)
------------------

* Added flag --keep-comments.
* Improved comments handling.
* Modified behavior for removal whitespace around brackets.

